@@ -4,19 +4,20 @@ from tools_hjh.ThreadPool import ThreadPool
 
 
 def main():
-    testSql = 'insert into t1 select ? where not exists(select 1 from t1 where c1 = ?)'
+    rows = []
+    for idx in range(0, 10):
+        row = (idx, idx, idx)
+        rows.append(row)
     testDB = DBConn('sqlite', db='test.db')
-    tp = ThreadPool(64)
-    for idx in range(0, 9999):
-        tp.run(testDB.run, (testSql, (idx, idx)))
-    tp.wait()
+    num = testDB.insert('t1', rows, 'c1')
+    print(num)
     testDB.close()
 
 
 class DBConn:
     """ 维护一个关系型数据库连接池，目前支持oracle，pgsql，mysql，sqlite；支持简单的sql执行 """
 
-    def __init__(self, dbtype, host=None, port=None, db=None, user=None, pwd=None, poolsize=2, lib_dir=None):
+    def __init__(self, dbtype, host=None, port=None, db=None, user=None, pwd=None, poolsize=2, encoding='UTF-8', lib_dir=None):
         """ 初始化连接池
                 如果是sqlite，db这个参数是要显示给入的
                 如果是oracle，db给入的是sid或是servername都是可以的 """
@@ -57,7 +58,7 @@ class DBConn:
                                                     dsn=dsn,
                                                     max=poolsize,
                                                     increment=1,
-                                                    encoding="UTF-8")
+                                                    encoding=encoding)
             except:
                 dsn = cx_Oracle.makedsn(host, port, sid=db)
                 self.dbpool = cx_Oracle.SessionPool(user=user,
@@ -65,7 +66,7 @@ class DBConn:
                                                     dsn=dsn,
                                                     max=poolsize,
                                                     increment=1,
-                                                    encoding="UTF-8")
+                                                    encoding=encoding)
     
     def __run(self, sql, param=None):
         # 替换占位符
@@ -129,35 +130,50 @@ class DBConn:
             conn.close()
             return rs(tuple(col), rows)
         
-    def run(self, sql, param=None, wait=None):
+    def run(self, sql, param=None, wait=False):
         """ 执行点什么
         sql中的占位符可以统一使用“?”
         wait为True则会等待当前正在执行的sql，有bug，暂不处理，自用规避"""
-        if wait is None and self.dbtype == 'sqlite' and not sql.lower().strip().startswith("select"):
-            wait = True
-            
         if wait == True:
             self.runTp.run(self.__run, (sql, param))
             self.runTp.wait()
         else:
             return self.__run(sql, param)
         
-    def insert(self, table, rows):
+    def insert(self, table, rows, pks=[]):
         """ 往指定table中插入数据，rows是一个多个元组的列表，每个元组表示一组参数；或者是一个元组 """
-        paramNum = '?'
         if type(rows) == list and len(rows) > 0:
-            for _ in range(len(rows[0]) - 1):
-                paramNum = paramNum + ', ?'
-            sql = 'insert into ' + table + ' values(' + paramNum + ')' 
-            num = self.run(sql, rows)
+            row = rows[0]
         elif type(rows) == tuple:
-            for _ in range(len(rows) - 1):
-                paramNum = paramNum + ', ?'
-            sql = 'insert into ' + table + ' values(' + paramNum + ')' 
-            num = self.run(sql, rows)
+            row = rows
+            
+        sql2 = ''
+        pk_num = 0
+        if type(pks) == str:
+            pk_num = 1
+            sql2 = sql2 + pks + ' = ?'
+        elif type(pks) == list or type(pks) == tuple:
+            pk_num = len(pks)
+            for pk in pks:
+                sql2 = sql2 + pk + ' = ? and '
+            sql2 = sql2.rstrip('and ')
+            
+        paramNum = '?'
+        for _ in range(len(row) - 1 - pk_num):
+            paramNum = paramNum + ', ?'
+            
+        if self.dbtype == 'oracle':
+            if len(pks) == 0:
+                sql = 'insert into ' + table + ' select ' + paramNum + ' from dual'
+            else:
+                sql = 'insert into ' + table + ' select ' + paramNum + ' from dual where not exists(select 1 from ' + table + ' where ' + sql2 + ')'
         else:
-            num = 0
-        return num
+            if len(pks) == 0:
+                sql = 'insert into ' + table + ' select ' + paramNum
+            else:
+                sql = 'insert into ' + table + ' select ' + paramNum + ' where not exists(select 1 from ' + table + ' where ' + sql2 + ')'
+        
+        return self.run(sql, rows)
                 
     def close(self):
         try:
