@@ -3,6 +3,10 @@ import time
 import os
 
 
+def main():
+    pass
+
+
 def locattime():
     """ 返回当前时间，格式%Y-%m-%d %H:%M:%S """
     return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
@@ -31,7 +35,7 @@ def sql_remove_comments(text):
         else:
             sql_line = line
         sql = sql + ' ' + sql_line
-    sql = spacesmerge(sql.replace('\n',' '))
+    sql = spacesmerge(sql.replace('\n', ' '))
     return sql
 
 
@@ -184,3 +188,28 @@ def linemergealign(str_1, str_2, iscompare=False):
         else:
             str_ = str_ + str1 + ' ' * (strlennum - len(str1) + 1) + str2 + '\n'
     return str_.strip()
+
+
+def picturesFolder2PDF(sourcePath, targetPDF):
+    from PIL import Image
+    files = os.listdir(sourcePath)
+    picFiles = []
+    for file in files:
+        if file.endswith('.jpg') or file.endswith('.png'):
+            file = sourcePath + '/' + file
+            picFiles.append(file)
+    picFiles.sort()
+    outFDF = Image.open(picFiles[0])
+    picFiles.pop(0)
+    sources = []
+    for file in picFiles:
+        png_file = Image.open(file)
+        if png_file.mode == "RGB":
+            png_file = png_file.convert("RGB")
+        sources.append(png_file)    
+        
+    outFDF.save(targetPDF, "pdf", save_all=True, append_images=sources)
+
+
+if __name__ == '__main__':
+    main()
